<?php
/**
 * Danish language file
 *
 * @author     Lars Næsbye Christensen <larsnaesbye@stud.ku.dk>
 */
 
$lang['menu'] = 'Brugerstyring'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(brugervalidering er ikke tilgængelig)';
$lang['nosupport']   = '(brugerstyring er ikke understøttet)';

$lang['badauth']     = 'ugyldig valideringsmekanisme';     // should never be displayed!

$lang['user_id']     = 'Bruger';
$lang['user_pass']   = 'Adgangskode';
$lang['user_name']   = 'Navn';
$lang['user_mail']   = 'E-mail';
$lang['user_groups'] = 'Grupper';

$lang['field']       = 'Felt';
$lang['value']       = 'Værdi';
$lang['add']         = 'Tilføj';
$lang['delete']      = 'Slet';
$lang['delete_selected'] = 'Slet valgte';
$lang['edit']        = 'Rediger';
$lang['edit_prompt'] = 'Rediger denne bruger';
$lang['modify']      = 'Gem ændringer';
$lang['search']      = 'Søg';
$lang['search_prompt'] = 'Udfør søgning';
$lang['clear']       = 'Nulstil søgefilter';
$lang['filter']      = 'Filter';

$lang['summary']     = 'Viser brugerne %1$d-%2$d ud af %3$d fundne. %4$d brugere totalt.';
$lang['nonefound']   = 'Ingen brugere fundet. %d brugere totalt.';
$lang['delete_ok']   = '%d brugere slettet';
$lang['delete_fail'] = '%d kunne ikke slettes.';
$lang['update_ok']   = 'Bruger opdateret korrekt';
$lang['update_fail'] = 'Brugeropdatering mislykkedes';
$lang['update_exists'] = 'Ændring af brugernavn mislykkedes, det valgte brugernavn (%s) er allerede optaget (andre ændringer vil blive udført).';

$lang['start']  = 'start';
$lang['prev']   = 'forrige';
$lang['next']   = 'næste';
$lang['last']   = 'sidste';

$lang['edit_usermissing'] = 'Den valgte bruger blev ikke fundet, brugernavnet kan være slettet eller ændret andetsteds.';
$lang['user_notify'] = 'Meddel bruger';
$lang['note_notify'] = 'Meddelelses emails er kun sendt hvis brugeren er givet et nyt kodeord.';
$lang['note_group'] = 'Nye brugere vil blive tilføjet til standard gruppen (%s) hvis ingen gruppe er opgivet.';
$lang['add_ok'] = 'Bruger succesfuldt tilføjet';
$lang['add_fail'] = 'Bruger tilføjelse mislykkedes';
$lang['notify_ok'] = 'Meddelelses email sendt';
$lang['notify_fail'] = 'Meddelelses email kunne ikke sendes';
